pub struct DccService { /* private fields */ }Expand description
The Dynamic Context Core service.
Manages the cold-path analysis loop, GORNA arbitration, and agent coordination.
Implementations
Sourceimpl DccService
impl DccService
Sourcepub fn register_agent(&self, agent: Arc<Mutex<dyn Agent>>, priority: f32)
pub fn register_agent(&self, agent: Arc<Mutex<dyn Agent>>, priority: f32)
Registers an agent with a priority value.
Higher priority values mean the agent is updated first in each frame.
Sourcepub fn event_sender(&self) -> Sender<TelemetryEvent>
pub fn event_sender(&self) -> Sender<TelemetryEvent>
Returns a sender handle to submit events to the DCC.
Sourcepub fn get_context(&self) -> Context
pub fn get_context(&self) -> Context
Returns the current context.
Sourcepub fn update_agents(&self, context: &mut EngineContext<'_>)
pub fn update_agents(&self, context: &mut EngineContext<'_>)
Updates all registered agents in priority order.
This is called each frame by the engine loop.
Sourcepub fn execute_agents(&self)
pub fn execute_agents(&self)
Executes all registered agents in priority order.
Called each frame after update_agents.
Each agent performs its primary work (e.g., the RenderAgent renders).
Sourcepub fn agent_count(&self) -> usize
pub fn agent_count(&self) -> usize
Returns the number of registered agents.